Enum EdgeTransportTelemetry
pub enum EdgeTransportTelemetry<N, P>{
Loopback(P),
Neighbor(N),
}Expand description
Enum representing different types of telemetry data used by the CT mechanism.
Variants
Loopback(P)
Telemetry data looping the traffic through multiple peers back to self.
Does not require a cooperating peer.
Neighbor(N)
Immediate neighbor telemetry data.
Assumes a cooperating immediate peer to receive responses for telemetry construction