Trait ProbingTrafficGeneration
pub trait ProbingTrafficGeneration {
// Required method
fn build(&self) -> Pin<Box<dyn Stream<Item = ProbeRouting> + Send>>;
}Expand description
A trait for types that can produce a stream of probing traffic routes.
The basic assumption is that the implementor will provide the logic to choose suitable route candidates for cover traffic based on a custom algorithm.
The implementor should ensure that the produced routes are indefinite, since the exhaustion of the stream might result in termination of the cover traffic generation.